==> nextcloud-app-notes-4.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/notes/l10n/fa.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "یادداشت ها",
    "Error" : "خطا",
    "New note" : "یادداشت جدید",
    "Distraction-free notes and writing" : "یادداشت ها و نوشتن بدون حواس پرتی",
    "Deleted {title}" : "حذف {عنوان}",
    "There are unsaved notes. Leaving the page will discard all changes!" : "یادداشتهای ذخیره نشده وجود دارد. ترک صفحه باعث می شود همه تغییرات از بین بروند!",
    "Settings" : "تنظیمات",
    "Folder to store your notes" : "پوشه برای ذخیره یادداشت های خود",
    "path to notes" : "مسیر یادداشت ها",
    "File extension for new notes" : "پسوند پرونده برای یادداشتهای جدید",
    "No notes yet" : "هنوز هیچ یادداشتی وجود ندارد",
    "All notes" : "همه یادداشت ها",
    "Categories" : "دسته بندی ها",
    "Loading …" : "بارگذاری …",
    "Today" : "Today",
    "Yesterday" : "دیروز",
    "This week" : "این هفته",
    "Last week" : "هفته گذشته",
    "This month" : "این ماه",
    "Last month" : "ماه گذشته",
    "Rename" : "تغییرنام",
    "Delete note" : "حذف یادداشت",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "افزودن به علاقه مندی ها",
    "Empty note" : "یادداشت خالی",
    "Write …" : "نوشتن …",
    "Details" : "جزئیات",
    "Edit" : "ویرایش کردن",
    "Preview" : "پیش نمایش",
    "Exit full screen" : "خروج از تمام صفحه",
    "Full screen" : "تمام صفحه",
    "Save failed. Click to retry." : "ذخیره نشد. برای امتحان دوباره کلیک کنید",
    "Set category" : "تنظیم مجموعه",
    "Category" : "دسته‌بندی",
    "Uncategorized" : "دستهبندی نشده",
    "Click here to save manually" : "برای ذخیره دستی اینجا را کلیک کنید",
    "Saving failed!" : "پس انداز نشد!",
    "Last modified: {date}" : "آخرین اصلاح: {تاریخ}",
    "Note has unsaved changes" : "توجه داشته باشید تغییرات ذخیره نشده دارد",
    "Subcategory" : "زیر مجموعه",
    "_%n word_::_%n words_" : ["%n کلمه","%n کلمه"],
    "Write down your thoughts without any distractions." : "افکار خود را بدون هیچ گونه حواس پرتی بنویسید.",
    "Use Markdown markups to style your text." : "برای نشان دادن متن خود از نشانگرهای Markdown استفاده کنید.",
    "Organize your notes in categories." : "یادداشت های خود را در دسته بندی ها ترتیب دهید.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "برای دسترسی به یادداشت های خود از همه جا ، برنامه تلفن همراه خود را نصب کنید.",
    "Android app" : "اپ اندروید",
    "iOS app" : "اپ iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "نوشتن یادداشت را با کلیک کردن روی \"{newnote}\" در ناوبری برنامه شروع کنید.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "شما می توانید زیر شاخه ها با استفاده از به عنوان حائل بین دسته پدر و مادر و زیرشاخه، به عنوان مثال، ایجاد \"/\" \"{پدر و مادر} / {زیر}\".",
    "Updating settings has failed." : "به روزرسانی تنظیمات انجام نشد.",
    "Fetching notes has failed." : "ثبت نام یادداشت انجام نشد.",
    "Fetching note {id} has failed." : "یادداشت برداری {id} انجام نشد.",
    "Creating new note has failed." : "ایجاد یادداشت جدید انجام نشد.",
    "Deleting note {id} has failed." : "حذف یادداشت {شناسه} انجام نشد.",
    "Toggling favorite for note {id} has failed." : "روشن نیست مورد علاقه برای توجه داشته باشید {id} تعریف شکست خورده است.",
    "Updating the note's category has failed. Is the target directory writable?" : "به روزرسانی دسته یادداشت انجام نشد. آیا فهرست مسیر قابل نوشتن است؟",
    "Updating the category for note {id} has failed." : "به روزرسانی دسته برای یادداشت {id} انجام نشد.",
    "Development Mode" : "حالت توسعه",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "به نظر می رسد که برنامه یادداشت ها از یک منبع توسعه نصب شده است. لطفاً آن را از طریق رسمی  نصب کنید <a href=\"%1$s\">فروشگاه برنامه نکست کلود</a>بجای.اگر می خواهید برنامه Notes توسط خودتان بسازید ، لطفاً دنبال کنید <a href=\"%2$s\">دستورالعمل های توسعه دهنده</a>."
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-app-notes-4.1.0-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/notes/l10n/fa.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "یادداشت ها",
    "Reading notes from filesystem has failed." : "خواندن یادداشت ها از پوشه ی سیستم با شکست مواجه شده است",
    "Error" : "خطا",
    "New note" : "یادداشت جدید",
    "Distraction-free notes and writing" : "یادداشت ها و نوشتن بدون حواس پرتی",
    "Please see Nextcloud server log for details." : "لطفا لاگ سرور nextcloud را برای جزییات بیشتر مشاهده نمایید .",
    "Deleted {title}" : "حذف شده {عنوان}",
    "Note recovered" : "یادداشت بازیابی شده",
    "There are unsaved notes. Leaving the page will discard all changes!" : "یادداشتهای ذخیره نشده وجود دارد. ترک صفحه باعث می شود همه تغییرات از بین بروند!",
    "Settings" : "تنظیمات",
    "Folder to store your notes" : "پوشه برای ذخیره یادداشت های خود",
    "path to notes" : "مسیر یادداشت ها",
    "File extension for new notes" : "پسوند پرونده برای یادداشتهای جدید",
    "No notes yet" : "هنوز هیچ یادداشتی وجود ندارد",
    "All notes" : "همه یادداشت ها",
    "Categories" : "دسته بندی ها",
    "Loading …" : "بارگذاری …",
    "Today" : "Today",
    "Yesterday" : "دیروز",
    "This week" : "این هفته",
    "Last week" : "هفته گذشته",
    "This month" : "این ماه",
    "Last month" : "ماه گذشته",
    "Rename" : "تغییرنام",
    "Note's title" : "موضوع یادداشت ها",
    "Delete note" : "حذف یادداشت",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "افزودن به علاقه مندی ها",
    "Error during preparing note for deletion." : "در هنگام آماده سازی یادداشت برای حذف خطایی رخ داده است",
    "Use current version" : "از نسخه فعلی استفاده کنید",
    "Empty note" : "یادداشت خالی",
    "Write …" : "نوشتن …",
    "Details" : "جزئیات",
    "Edit" : "ویرایش کردن",
    "Preview" : "پیش نمایش",
    "Exit full screen" : "خروج از تمام صفحه",
    "Full screen" : "تمام صفحه",
    "Save failed. Click to retry." : "ذخیره نشد. برای امتحان دوباره کلیک کنید",
    "Set category" : "تنظیم مجموعه",
    "Category" : "دسته‌بندی",
    "Uncategorized" : "دستهبندی نشده",
    "Click here to save manually" : "برای ذخیره دستی اینجا را کلیک کنید",
    "Saving failed!" : "پس انداز نشد!",
    "Last modified: {date}" : "آخرین اصلاح: {تاریخ}",
    "Note has unsaved changes" : "توجه داشته باشید تغییرات ذخیره نشده دارد",
    "Subcategory" : "زیر مجموعه",
    "_%n word_::_%n words_" : ["%n کلمه","%n کلمه"],
    "Write down your thoughts without any distractions." : "افکار خود را بدون هیچ گونه حواس پرتی بنویسید.",
    "Use Markdown markups to style your text." : "برای نشان دادن متن خود از نشانگرهای Markdown استفاده کنید.",
    "Organize your notes in categories." : "یادداشت های خود را در دسته بندی ها ترتیب دهید.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "برای دسترسی به یادداشت های خود از همه جا ، برنامه تلفن همراه خود را نصب کنید.",
    "Android app" : "اپ اندروید",
    "iOS app" : "اپ iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "نوشتن یادداشت را با کلیک کردن روی \"{newnote}\" در ناوبری برنامه شروع کنید.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "شما می توانید زیر شاخه ها با استفاده از به عنوان حائل بین دسته پدر و مادر و زیرشاخه، به عنوان مثال، ایجاد \"/\" \"{پدر و مادر} / {زیر}\".",
    "Note not found." : "یادداشتی یافت نشد",
    "Note is locked." : "یادداشت قفل شده است",
    "Updating settings has failed." : "به روزرسانی تنظیمات انجام نشد.",
    "Error from Nextcloud server: {msg}" : "خطا از سرور نکست کلود : {msg}",
    "Fetching notes has failed." : "ثبت نام یادداشت انجام نشد.",
    "Fetching note {id} has failed." : "یادداشت برداری {id} انجام نشد.",
    "Creating new note has failed." : "ایجاد یادداشت جدید انجام نشد.",
    "Deleting note {id} has failed." : "حذف یادداشت {شناسه} انجام نشد.",
    "Toggling favorite for note {id} has failed." : "روشن نیست مورد علاقه برای توجه داشته باشید {id} تعریف شکست خورده است.",
    "Updating the note's category has failed. Is the target directory writable?" : "به روزرسانی دسته یادداشت انجام نشد. آیا فهرست مسیر قابل نوشتن است؟",
    "Updating the category for note {id} has failed." : "به روزرسانی دسته برای یادداشت {id} انجام نشد.",
    "Development Mode" : "حالت توسعه",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "به نظر می رسد که برنامه یادداشت ها از یک منبع توسعه نصب شده است. لطفاً آن را از طریق رسمی  نصب کنید <a href=\"%1$s\">فروشگاه برنامه نکست کلود</a>بجای.اگر می خواهید برنامه Notes توسط خودتان بسازید ، لطفاً دنبال کنید <a href=\"%2$s\">دستورالعمل های توسعه دهنده</a>."
},
"nplurals=2; plural=(n > 1);");
